@@ -2,7 +2,7 @@ from snowmobile import snowconn
 from snowmobile import snowcreds
 from snowmobile import snowquery
 from snowmobile import snowloader
-from snowmobile import scriptparser
+from snowmobile import snowscripter
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
